import { useEffect, useState } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import { fetchChatHistory, fetchInboxList, selectChat } from '../store/slices/inboxSlice';

export default function InboxList() {
    const dispatch = useDispatch();
    const { inboxList, inboxStatus: status, error, selectedChat } = useSelector((state) => state.inbox);
    const [activeToggle, setActiveToggle] = useState('all');
    const [activeSelect, setActiveSelect] = useState('all');
    const toggleOptions = [
        { name: '全部', value: 'all' },
        { name: '首次建联', value: 'initial' },
        { name: '砍价邮件', value: 'bargain' },
        { name: '合作追踪', value: 'coop' },
    ];

    useEffect(() => {
        dispatch(fetchInboxList());
    }, [dispatch]);

    useEffect(() => {
        if (inboxList.length > 0) {
            // dispatch(selectChat(inboxList[0]));
            // dispatch(fetchChatHistory(inboxList[0].id));
        }
    }, [dispatch, inboxList]);

    const handleSelectChat = (item) => {
        dispatch(selectChat(item));
        dispatch(fetchChatHistory(item.id));
    };

    return (
        <div className='inbox-list-container'>
            <div className='breadcrumb'>
                <div className='breadcrumb-item'>Creator Inbox</div>
            </div>

            <div className='list-filter mb-2'>
                <div className='toggle-list'>
                    {toggleOptions.map((option) => (
                        <div
                            key={option.value}
                            className={`toggle-option ${option.value === activeToggle ? 'active' : ''}`}
                            onClick={() => setActiveToggle(option.value)}
                        >
                            {option.name}
                        </div>
                    ))}
                </div>
                <div className='select-list'>
                    <span
                        className={`select-option ${activeSelect === 'all' ? 'active' : ''}`}
                        onClick={() => setActiveSelect('all')}
                    >
                        All
                    </span>
                    <span
                        className={`select-option ${activeSelect === 'unread' ? 'active' : ''}`}
                        onClick={() => setActiveSelect('unread')}
                    >
                        Unread
                    </span>
                </div>
                <div className='actions'>批量</div>
            </div>

            <div className='list-content'>
                {status === 'loading' && <div>Loading...</div>}
                {status === 'failed' && <div>Error: {error}</div>}
                {status === 'succeeded' && inboxList.length > 0 &&
                    inboxList.map((item) => (
                        <div
                            key={item.id}
                            className={`list-item ${selectedChat.id === item.id ? 'active' : ''}`}
                            onClick={() => handleSelectChat(item)}
                        >
                            <div className='list-item-left'>
                                <div className='list-item-left-avatar'>
                                    <img src={item.avatar} alt={item.name} />
                                </div>
                                <div className='list-item-info'>
                                    <div className='list-name fw-bold'>{item.name}</div>
                                    <div className='list-message'>{item.message}</div>
                                </div>
                            </div>
                            <div className='list-item-right'>
                                <div className='list-item-right-time'>{item.date}</div>
                                {item.unreadMessageCount > 0 && (
                                    <div className='list-item-right-badge'>{item.unreadMessageCount}</div>
                                )}
                            </div>
                        </div>
                    ))}
            </div>
        </div>
    );
}
